const std = @import("std");

// Although this function looks imperative, note that its job is to
// declaratively construct a build graph that will be executed by an external
// runner.
pub fn build(b: *std.Build) void {
    // Standard target options allows the person running `zig build` to choose
    // what target to build for. Here we do not override the defaults, which
    // means any target is allowed, and the default is native. Other options
    // for restricting supported target set are available.
    const target = b.standardTargetOptions(.{});

    // Standard optimization options allow the person running `zig build` to select
    // between Debug, ReleaseSafe, ReleaseFast, and ReleaseSmall. Here we do not
    // set a preferred release mode, allowing the user to decide how to optimize.
    const optimize = b.standardOptimizeOption(.{});

    const opt_elf64 = b.option(bool, "elf64", "ELF 64 bit").?;
    const opt_file = b.option(bool, "file", "Get auxiliary vectors from /proc/self/auxv") orelse false;

    const lib = b.addStaticLibrary(.{
        .name = "getauxval_backport",
        .target = target,
        .optimize = optimize,
    });

    lib.linkLibC();

    lib.addCSourceFile(.{
        .file = b.path("src/getauxval_backport.c"),
        .flags = &.{
            if (!opt_elf64) "-DGETAUXVAL_BACKPORT_ELF32" else "",
            if (opt_file) "-DGETAUXVAL_BACKPORT_FILE" else "",
        },
    });

    b.installArtifact(lib);
}
